package
Version:
v0.0.0-...-f60a8b2
Opens a new window with list of versions in this module.
Published: Dec 11, 2019
License: GPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Arc struct {
Title string `json:"title"`
Story []string `json:"story"`
Options []struct {
Text string `json:"text"`
Arc string `json:"arc"`
} `json:"options"`
}
type StoryHandler struct {
Arcs map[string]Arc
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.